""" Contains all the data models used in inputs/outputs """

from .account import Account
from .account_list_response import AccountListResponse
from .adapter import Adapter
from .adapter_cascading_configuration import AdapterCascadingConfiguration
from .adapter_cascading_configuration_specificity import AdapterCascadingConfigurationSpecificity
from .adapter_cascading_configuration_type import AdapterCascadingConfigurationType
from .adapter_configuration import AdapterConfiguration
from .adapter_list_response import AdapterListResponse
from .analytics_module import AnalyticsModule
from .analytics_module_layout import AnalyticsModuleLayout
from .annotation import Annotation
from .annotation_field import AnnotationField
from .annotation_field_type import AnnotationFieldType
from .annotation_field_value import AnnotationFieldValue
from .annotation_field_value_tags import AnnotationFieldValueTags
from .annotation_field_values_request import AnnotationFieldValuesRequest
from .annotation_field_values_request_tags import AnnotationFieldValuesRequestTags
from .annotation_field_values_response import AnnotationFieldValuesResponse
from .annotation_metadata import AnnotationMetadata
from .annotation_stream_type import AnnotationStreamType
from .annotation_tags import AnnotationTags
from .annotation_template import AnnotationTemplate
from .annotation_template_list_response import AnnotationTemplateListResponse
from .annotation_template_tags import AnnotationTemplateTags
from .annotation_type import AnnotationType
from .application_context import ApplicationContext
from .audio_device import AudioDevice
from .authentication import Authentication
from .auto_resolve_event_trigger_condition import AutoResolveEventTriggerCondition
from .auto_resolve_event_trigger_condition_type import AutoResolveEventTriggerConditionType
from .aws_info import AwsInfo
from .aws_info_output_format import AwsInfoOutputFormat
from .base_event import BaseEvent
from .base_event_metadata import BaseEventMetadata
from .base_event_stream_type import BaseEventStreamType
from .base_event_tags import BaseEventTags
from .base_event_trigger_predicate import BaseEventTriggerPredicate
from .base_event_type import BaseEventType
from .battery import Battery
from .battery_event_trigger_condition import BatteryEventTriggerCondition
from .battery_event_trigger_condition_conditions import BatteryEventTriggerConditionConditions
from .battery_event_trigger_condition_operator import BatteryEventTriggerConditionOperator
from .battery_event_trigger_condition_type import BatteryEventTriggerConditionType
from .begin_upload_request import BeginUploadRequest
from .begin_upload_response import BeginUploadResponse
from .billing_info import BillingInfo
from .bit_condition import BitCondition
from .bitset import Bitset
from .bitset_event_trigger_condition import BitsetEventTriggerCondition
from .bitset_event_trigger_condition_operator import BitsetEventTriggerConditionOperator
from .bitset_event_trigger_condition_type import BitsetEventTriggerConditionType
from .bitset_view_configuration import BitsetViewConfiguration
from .board import Board
from .bounding_box import BoundingBox
from .camera import Camera
from .capture_session import CaptureSession
from .capture_session_tags import CaptureSessionTags
from .challenge import Challenge
from .challenge_type import ChallengeType
from .change_password_request import ChangePasswordRequest
from .channel import Channel
from .channel_list_response import ChannelListResponse
from .chargebee_customer import ChargebeeCustomer
from .chat_message import ChatMessage
from .chat_message_list_response import ChatMessageListResponse
from .chat_message_request import ChatMessageRequest
from .check_sso_request import CheckSsoRequest
from .check_sso_result import CheckSsoResult
from .cloud_file import CloudFile
from .cloud_file_list_response import CloudFileListResponse
from .cloud_file_tags import CloudFileTags
from .command import Command
from .command_delivery_event import CommandDeliveryEvent
from .command_delivery_event_metadata import CommandDeliveryEventMetadata
from .command_delivery_event_stream_type import CommandDeliveryEventStreamType
from .command_delivery_event_tags import CommandDeliveryEventTags
from .command_delivery_event_type import CommandDeliveryEventType
from .command_list_response import CommandListResponse
from .command_parameter import CommandParameter
from .command_parameter_meta import CommandParameterMeta
from .command_progress import CommandProgress
from .command_query import CommandQuery
from .command_request import CommandRequest
from .command_request_list_response import CommandRequestListResponse
from .command_response import CommandResponse
from .command_response_stream_type import CommandResponseStreamType
from .command_response_tags import CommandResponseTags
from .command_stream_type import CommandStreamType
from .command_tags import CommandTags
from .command_template import CommandTemplate
from .command_template_list_response import CommandTemplateListResponse
from .command_template_parameter_meta import CommandTemplateParameterMeta
from .command_template_tags import CommandTemplateTags
from .comment import Comment
from .comment_metadata import CommentMetadata
from .comment_stream_type import CommentStreamType
from .comment_tags import CommentTags
from .comment_type import CommentType
from .complete_upload_request import CompleteUploadRequest
from .confirm_forgot_password_request import ConfirmForgotPasswordRequest
from .create_event_trigger_group_request import CreateEventTriggerGroupRequest
from .create_event_trigger_group_request_tags import CreateEventTriggerGroupRequestTags
from .create_intervention_response import CreateInterventionResponse
from .create_intervention_response_intervention_type import CreateInterventionResponseInterventionType
from .create_intervention_response_type import CreateInterventionResponseType
from .create_service_account_request import CreateServiceAccountRequest
from .create_service_account_request_tags import CreateServiceAccountRequestTags
from .create_service_account_response import CreateServiceAccountResponse
from .create_user_request import CreateUserRequest
from .create_user_request_language import CreateUserRequestLanguage
from .create_user_request_region import CreateUserRequestRegion
from .create_user_request_sms_opt_in_status import CreateUserRequestSmsOptInStatus
from .create_user_request_tags import CreateUserRequestTags
from .create_user_request_units import CreateUserRequestUnits
from .custom_event import CustomEvent
from .custom_event_batch_request import CustomEventBatchRequest
from .custom_event_metadata import CustomEventMetadata
from .custom_event_severity import CustomEventSeverity
from .custom_event_stream_type import CustomEventStreamType
from .custom_event_tags import CustomEventTags
from .custom_event_type import CustomEventType
from .datapoint_event import DatapointEvent
from .datapoint_event_metadata import DatapointEventMetadata
from .datapoint_event_severity import DatapointEventSeverity
from .datapoint_event_stream_type import DatapointEventStreamType
from .datapoint_event_tags import DatapointEventTags
from .datapoint_event_type import DatapointEventType
from .device import Device
from .device_application_configuration import DeviceApplicationConfiguration
from .device_application_configuration_configuration_map import DeviceApplicationConfigurationConfigurationMap
from .device_blob_data import DeviceBlobData
from .device_configuration import DeviceConfiguration
from .device_configuration_document import DeviceConfigurationDocument
from .device_configuration_document_tags import DeviceConfigurationDocumentTags
from .device_configuration_template import DeviceConfigurationTemplate
from .device_configuration_template_list_response import DeviceConfigurationTemplateListResponse
from .device_configuration_template_tags import DeviceConfigurationTemplateTags
from .device_credentials import DeviceCredentials
from .device_details import DeviceDetails
from .device_details_list_response import DeviceDetailsListResponse
from .device_details_tags import DeviceDetailsTags
from .device_details_type import DeviceDetailsType
from .device_diagnostics_configuration import DeviceDiagnosticsConfiguration
from .device_disk_configuration import DeviceDiskConfiguration
from .device_follower import DeviceFollower
from .device_list_response import DeviceListResponse
from .device_offline_event import DeviceOfflineEvent
from .device_offline_event_metadata import DeviceOfflineEventMetadata
from .device_offline_event_severity import DeviceOfflineEventSeverity
from .device_offline_event_stream_type import DeviceOfflineEventStreamType
from .device_offline_event_tags import DeviceOfflineEventTags
from .device_offline_event_type import DeviceOfflineEventType
from .device_online_event import DeviceOnlineEvent
from .device_online_event_metadata import DeviceOnlineEventMetadata
from .device_online_event_severity import DeviceOnlineEventSeverity
from .device_online_event_stream_type import DeviceOnlineEventStreamType
from .device_online_event_tags import DeviceOnlineEventTags
from .device_online_event_type import DeviceOnlineEventType
from .device_port_forwarding_configuration import DevicePortForwardingConfiguration
from .device_provisioning import DeviceProvisioning
from .device_provisioning_request import DeviceProvisioningRequest
from .device_query import DeviceQuery
from .device_query_type import DeviceQueryType
from .device_reported_configuration_state import DeviceReportedConfigurationState
from .device_resources_configuration import DeviceResourcesConfiguration
from .device_ros_configuration import DeviceRosConfiguration
from .device_ros_state import DeviceRosState
from .device_scope import DeviceScope
from .device_scope_types_item import DeviceScopeTypesItem
from .device_state import DeviceState
from .device_state_env import DeviceStateEnv
from .device_stream_configuration import DeviceStreamConfiguration
from .device_stream_configuration_quality import DeviceStreamConfigurationQuality
from .device_stream_configuration_tags import DeviceStreamConfigurationTags
from .device_stream_custom_configuration import DeviceStreamCustomConfiguration
from .device_stream_custom_configuration_type import DeviceStreamCustomConfigurationType
from .device_stream_directory_watch_configuration import DeviceStreamDirectoryWatchConfiguration
from .device_stream_directory_watch_configuration_file_type import DeviceStreamDirectoryWatchConfigurationFileType
from .device_stream_directory_watch_configuration_type import DeviceStreamDirectoryWatchConfigurationType
from .device_stream_file_tail_configuration import DeviceStreamFileTailConfiguration
from .device_stream_file_tail_configuration_file_format import DeviceStreamFileTailConfigurationFileFormat
from .device_stream_file_tail_configuration_type import DeviceStreamFileTailConfigurationType
from .device_stream_hardware_configuration import DeviceStreamHardwareConfiguration
from .device_stream_hardware_configuration_hardware_type import DeviceStreamHardwareConfigurationHardwareType
from .device_stream_hardware_configuration_quality import DeviceStreamHardwareConfigurationQuality
from .device_stream_hardware_configuration_type import DeviceStreamHardwareConfigurationType
from .device_stream_ros_localization_configuration import DeviceStreamRosLocalizationConfiguration
from .device_stream_ros_localization_configuration_type import DeviceStreamRosLocalizationConfigurationType
from .device_stream_ros_topic_configuration import DeviceStreamRosTopicConfiguration
from .device_stream_ros_topic_configuration_type import DeviceStreamRosTopicConfigurationType
from .device_stream_ros_transform_tree_configuration import DeviceStreamRosTransformTreeConfiguration
from .device_stream_ros_transform_tree_configuration_type import DeviceStreamRosTransformTreeConfigurationType
from .device_stream_transform_configuration import DeviceStreamTransformConfiguration
from .device_tags import DeviceTags
from .device_telemetry_configuration import DeviceTelemetryConfiguration
from .device_teleop_configuration import DeviceTeleopConfiguration
from .device_teleop_custom_stream_configuration import DeviceTeleopCustomStreamConfiguration
from .device_teleop_custom_stream_configuration_mode import DeviceTeleopCustomStreamConfigurationMode
from .device_teleop_custom_stream_configuration_numeric_control_visualization import (
    DeviceTeleopCustomStreamConfigurationNumericControlVisualization,
)
from .device_teleop_custom_stream_configuration_quality import DeviceTeleopCustomStreamConfigurationQuality
from .device_teleop_custom_stream_configuration_rtc_stream_type import (
    DeviceTeleopCustomStreamConfigurationRtcStreamType,
)
from .device_teleop_hardware_stream_configuration import DeviceTeleopHardwareStreamConfiguration
from .device_teleop_hardware_stream_configuration_hardware_type import (
    DeviceTeleopHardwareStreamConfigurationHardwareType,
)
from .device_teleop_hardware_stream_configuration_mode import DeviceTeleopHardwareStreamConfigurationMode
from .device_teleop_hardware_stream_configuration_quality import DeviceTeleopHardwareStreamConfigurationQuality
from .device_teleop_hardware_stream_configuration_rtc_stream_type import (
    DeviceTeleopHardwareStreamConfigurationRtcStreamType,
)
from .device_teleop_ros_stream_configuration import DeviceTeleopRosStreamConfiguration
from .device_teleop_ros_stream_configuration_audio_codec import DeviceTeleopRosStreamConfigurationAudioCodec
from .device_teleop_ros_stream_configuration_mode import DeviceTeleopRosStreamConfigurationMode
from .device_teleop_ros_stream_configuration_numeric_control_visualization import (
    DeviceTeleopRosStreamConfigurationNumericControlVisualization,
)
from .device_teleop_ros_stream_configuration_quality import DeviceTeleopRosStreamConfigurationQuality
from .device_teleop_ros_stream_configuration_topic_type import DeviceTeleopRosStreamConfigurationTopicType
from .device_type import DeviceType
from .email_configuration import EmailConfiguration
from .email_configuration_email_type import EmailConfigurationEmailType
from .email_configuration_language import EmailConfigurationLanguage
from .email_configuration_list_response import EmailConfigurationListResponse
from .event_counts import EventCounts
from .event_counts_by_device import EventCountsByDevice
from .event_export_sheet_request import EventExportSheetRequest
from .event_export_sheet_result import EventExportSheetResult
from .event_filter import EventFilter
from .event_filter_event_types_item import EventFilterEventTypesItem
from .event_filter_severities_item import EventFilterSeveritiesItem
from .event_filter_types_item import EventFilterTypesItem
from .event_histogram import EventHistogram
from .event_histogram_entry import EventHistogramEntry
from .event_list_response import EventListResponse
from .event_query import EventQuery
from .event_query_event_types_item import EventQueryEventTypesItem
from .event_query_severities_item import EventQuerySeveritiesItem
from .event_query_types_item import EventQueryTypesItem
from .event_seek_query import EventSeekQuery
from .event_seek_query_direction import EventSeekQueryDirection
from .event_seek_query_event_types_item import EventSeekQueryEventTypesItem
from .event_seek_query_severities_item import EventSeekQuerySeveritiesItem
from .event_seek_query_types_item import EventSeekQueryTypesItem
from .event_sort import EventSort
from .event_sort_column import EventSortColumn
from .event_sort_order import EventSortOrder
from .event_trigger import EventTrigger
from .event_trigger_command import EventTriggerCommand
from .event_trigger_event_type import EventTriggerEventType
from .event_trigger_group import EventTriggerGroup
from .event_trigger_group_list_response import EventTriggerGroupListResponse
from .event_trigger_group_sms_tags import EventTriggerGroupSmsTags
from .event_trigger_group_tags import EventTriggerGroupTags
from .event_trigger_list_response import EventTriggerListResponse
from .event_trigger_severity import EventTriggerSeverity
from .event_trigger_sms_tags import EventTriggerSmsTags
from .event_trigger_tags import EventTriggerTags
from .exploration import Exploration
from .exploration_list_response import ExplorationListResponse
from .external_login_request import ExternalLoginRequest
from .file import File
from .file_info import FileInfo
from .filter_ import Filter
from .filter_types_item import FilterTypesItem
from .fleet import Fleet
from .fleet_list_response import FleetListResponse
from .fleet_tags import FleetTags
from .focused_datapoint import FocusedDatapoint
from .forgot_password_request import ForgotPasswordRequest
from .forwarding_configuration import ForwardingConfiguration
from .geo_ip import GeoIp
from .geo_json_icon import GeoJsonIcon
from .geo_json_layer import GeoJsonLayer
from .get_features_response import GetFeaturesResponse
from .get_features_response_features_item import GetFeaturesResponseFeaturesItem
from .goal import Goal
from .google_auth_request import GoogleAuthRequest
from .google_info import GoogleInfo
from .google_login_request import GoogleLoginRequest
from .google_sheet_parse_result import GoogleSheetParseResult
from .google_spreadsheet_inspection import GoogleSpreadsheetInspection
from .google_storage_export import GoogleStorageExport
from .google_storage_info import GoogleStorageInfo
from .google_storage_info_output_format import GoogleStorageInfoOutputFormat
from .group import Group
from .group_list_response import GroupListResponse
from .group_tags import GroupTags
from .health import Health
from .health_status import HealthStatus
from .http_integration import HttpIntegration
from .http_integration_basic_auth import HttpIntegrationBasicAuth
from .http_integration_basic_auth_type import HttpIntegrationBasicAuthType
from .http_integration_method import HttpIntegrationMethod
from .http_integration_no_auth import HttpIntegrationNoAuth
from .http_integration_no_auth_type import HttpIntegrationNoAuthType
from .hw_info import HwInfo
from .image import Image
from .image_annotation import ImageAnnotation
from .image_view_configuration import ImageViewConfiguration
from .image_view_configuration_mode import ImageViewConfigurationMode
from .ingest_stream_data import IngestStreamData
from .ingest_stream_data_tags import IngestStreamDataTags
from .ingest_stream_data_type import IngestStreamDataType
from .inspect_spreadsheet_request import InspectSpreadsheetRequest
from .inspect_spreadsheet_response import InspectSpreadsheetResponse
from .interval_event_filter import IntervalEventFilter
from .interval_event_filter_event_types_item import IntervalEventFilterEventTypesItem
from .interval_event_filter_interval import IntervalEventFilterInterval
from .interval_event_filter_severities_item import IntervalEventFilterSeveritiesItem
from .interval_event_filter_types_item import IntervalEventFilterTypesItem
from .intervention_request import InterventionRequest
from .intervention_request_controller_list_order import InterventionRequestControllerListOrder
from .intervention_request_intervention_type import InterventionRequestInterventionType
from .intervention_request_list_response import InterventionRequestListResponse
from .intervention_request_metadata import InterventionRequestMetadata
from .intervention_request_severity import InterventionRequestSeverity
from .intervention_request_stream_type import InterventionRequestStreamType
from .intervention_request_tags import InterventionRequestTags
from .intervention_request_type import InterventionRequestType
from .intervention_response import InterventionResponse
from .intervention_response_intervention_type import InterventionResponseInterventionType
from .intervention_response_metadata import InterventionResponseMetadata
from .intervention_response_stream_type import InterventionResponseStreamType
from .intervention_response_tags import InterventionResponseTags
from .intervention_response_type import InterventionResponseType
from .joystick_configuration import JoystickConfiguration
from .joystick_configuration_angular import JoystickConfigurationAngular
from .joystick_configuration_linear import JoystickConfigurationLinear
from .json_event_trigger_condition import JsonEventTriggerCondition
from .json_event_trigger_condition_type import JsonEventTriggerConditionType
from .kernel_info import KernelInfo
from .key_value import KeyValue
from .key_value_query import KeyValueQuery
from .key_value_tags import KeyValueTags
from .label import Label
from .labeled_polygon import LabeledPolygon
from .labeling_request_data import LabelingRequestData
from .layout_module_configuration import LayoutModuleConfiguration
from .layout_module_configuration_module_type import LayoutModuleConfigurationModuleType
from .localization import Localization
from .localization_view_configuration import LocalizationViewConfiguration
from .location import Location
from .location_module_parameters import LocationModuleParameters
from .location_view_configuration import LocationViewConfiguration
from .location_view_configuration_basemap import LocationViewConfigurationBasemap
from .location_viewport import LocationViewport
from .login_request import LoginRequest
from .login_result import LoginResult
from .looker_info import LookerInfo
from .looker_look import LookerLook
from .map_ import Map
from .module import Module
from .named_json_schema import NamedJsonSchema
from .named_json_schema_schema_type import NamedJsonSchemaSchemaType
from .network import Network
from .network_info import NetworkInfo
from .node_graph_integration import NodeGraphIntegration
from .node_info import NodeInfo
from .numeric_condition import NumericCondition
from .numeric_set_entry import NumericSetEntry
from .numeric_set_event_trigger_condition import NumericSetEventTriggerCondition
from .numeric_set_event_trigger_condition_operator import NumericSetEventTriggerConditionOperator
from .numeric_set_event_trigger_condition_type import NumericSetEventTriggerConditionType
from .numeric_view_configuration import NumericViewConfiguration
from .odometry import Odometry
from .on_demand_buffer import OnDemandBuffer
from .on_demand_buffer_buffer_type import OnDemandBufferBufferType
from .on_demand_presence_stream_item_group import OnDemandPresenceStreamItemGroup
from .on_demand_presence_stream_item_group_datapoint_type import OnDemandPresenceStreamItemGroupDatapointType
from .on_demand_presence_time_range import OnDemandPresenceTimeRange
from .on_demand_state import OnDemandState
from .on_demand_stream_presence import OnDemandStreamPresence
from .onvif_device import OnvifDevice
from .organization import Organization
from .organization_addon_billing_period import OrganizationAddonBillingPeriod
from .organization_flags_item import OrganizationFlagsItem
from .organization_invoice_billing_period import OrganizationInvoiceBillingPeriod
from .organization_plan import OrganizationPlan
from .organization_support_tier import OrganizationSupportTier
from .organization_supported_regions_item import OrganizationSupportedRegionsItem
from .os_info import OsInfo
from .overview_settings import OverviewSettings
from .pagerduty_info import PagerdutyInfo
from .partial_account import PartialAccount
from .partial_adapter import PartialAdapter
from .partial_annotation import PartialAnnotation
from .partial_annotation_metadata import PartialAnnotationMetadata
from .partial_annotation_stream_type import PartialAnnotationStreamType
from .partial_annotation_tags import PartialAnnotationTags
from .partial_annotation_template import PartialAnnotationTemplate
from .partial_annotation_template_tags import PartialAnnotationTemplateTags
from .partial_annotation_type import PartialAnnotationType
from .partial_channel import PartialChannel
from .partial_cloud_file import PartialCloudFile
from .partial_cloud_file_tags import PartialCloudFileTags
from .partial_command import PartialCommand
from .partial_command_stream_type import PartialCommandStreamType
from .partial_command_tags import PartialCommandTags
from .partial_command_template import PartialCommandTemplate
from .partial_command_template_parameter_meta import PartialCommandTemplateParameterMeta
from .partial_command_template_tags import PartialCommandTemplateTags
from .partial_comment import PartialComment
from .partial_comment_metadata import PartialCommentMetadata
from .partial_comment_stream_type import PartialCommentStreamType
from .partial_comment_tags import PartialCommentTags
from .partial_comment_type import PartialCommentType
from .partial_device import PartialDevice
from .partial_device_configuration_template import PartialDeviceConfigurationTemplate
from .partial_device_configuration_template_tags import PartialDeviceConfigurationTemplateTags
from .partial_device_tags import PartialDeviceTags
from .partial_device_type import PartialDeviceType
from .partial_email_configuration import PartialEmailConfiguration
from .partial_email_configuration_email_type import PartialEmailConfigurationEmailType
from .partial_email_configuration_language import PartialEmailConfigurationLanguage
from .partial_event_trigger import PartialEventTrigger
from .partial_event_trigger_event_type import PartialEventTriggerEventType
from .partial_event_trigger_group import PartialEventTriggerGroup
from .partial_event_trigger_group_sms_tags import PartialEventTriggerGroupSmsTags
from .partial_event_trigger_group_tags import PartialEventTriggerGroupTags
from .partial_event_trigger_severity import PartialEventTriggerSeverity
from .partial_event_trigger_sms_tags import PartialEventTriggerSmsTags
from .partial_event_trigger_tags import PartialEventTriggerTags
from .partial_fleet import PartialFleet
from .partial_fleet_tags import PartialFleetTags
from .partial_group import PartialGroup
from .partial_group_tags import PartialGroupTags
from .partial_http_integration import PartialHttpIntegration
from .partial_http_integration_method import PartialHttpIntegrationMethod
from .partial_node_graph_integration import PartialNodeGraphIntegration
from .partial_role import PartialRole
from .partial_role_tags import PartialRoleTags
from .partial_schedule import PartialSchedule
from .partial_schedule_type import PartialScheduleType
from .partial_sso_configuration import PartialSsoConfiguration
from .partial_sso_configuration_authentication_flow import PartialSsoConfigurationAuthenticationFlow
from .partial_stream import PartialStream
from .partial_stream_stream_type import PartialStreamStreamType
from .partial_team import PartialTeam
from .partial_team_tags import PartialTeamTags
from .partial_user import PartialUser
from .partial_user_language import PartialUserLanguage
from .partial_user_region import PartialUserRegion
from .partial_user_sms_opt_in_status import PartialUserSmsOptInStatus
from .partial_user_tags import PartialUserTags
from .partial_user_units import PartialUserUnits
from .partial_view import PartialView
from .partial_view_layout_type import PartialViewLayoutType
from .partial_view_tags import PartialViewTags
from .path import Path
from .physical_request_data import PhysicalRequestData
from .point_cloud import PointCloud
from .point_cloud_view_configuration import PointCloudViewConfiguration
from .poll_command_request import PollCommandRequest
from .port_forwarding_session_record import PortForwardingSessionRecord
from .port_forwarding_session_record_metadata import PortForwardingSessionRecordMetadata
from .port_forwarding_session_record_stream_type import PortForwardingSessionRecordStreamType
from .port_forwarding_session_record_tags import PortForwardingSessionRecordTags
from .port_forwarding_session_record_type import PortForwardingSessionRecordType
from .presence_event_trigger_condition import PresenceEventTriggerCondition
from .presence_event_trigger_condition_type import PresenceEventTriggerConditionType
from .quaternion import Quaternion
from .query_files_request import QueryFilesRequest
from .query_files_response import QueryFilesResponse
from .refresh_request import RefreshRequest
from .regex_event_trigger_condition import RegexEventTriggerCondition
from .regex_event_trigger_condition_type import RegexEventTriggerConditionType
from .reorder_request import ReorderRequest
from .reorder_request_item import ReorderRequestItem
from .resend_confirmation_code_request import ResendConfirmationCodeRequest
from .resend_invitation_request import ResendInvitationRequest
from .respond_to_new_password_required_challenge_request import RespondToNewPasswordRequiredChallengeRequest
from .role import Role
from .role_list_response import RoleListResponse
from .role_tags import RoleTags
from .ros_topic import RosTopic
from .rtc_info import RtcInfo
from .rtc_info_rtc_ice_server_protocol import RtcInfoRtcIceServerProtocol
from .rtc_info_rtc_ice_transport_policies_item import RtcInfoRtcIceTransportPoliciesItem
from .s3_export import S3Export
from .schedule import Schedule
from .schedule_list_response import ScheduleListResponse
from .schedule_type import ScheduleType
from .schedules_query import SchedulesQuery
from .scope_filter import ScopeFilter
from .scope_filter_types_item import ScopeFilterTypesItem
from .selection_request_data import SelectionRequestData
from .share import Share
from .share_list_response import ShareListResponse
from .sheet_parameters import SheetParameters
from .slack_auth_request import SlackAuthRequest
from .slack_info import SlackInfo
from .slack_webhook import SlackWebhook
from .sso_configuration import SsoConfiguration
from .sso_configuration_authentication_flow import SsoConfigurationAuthenticationFlow
from .sso_configuration_list_response import SsoConfigurationListResponse
from .sso_group_name_to_team_mapping import SsoGroupNameToTeamMapping
from .stateful_event import StatefulEvent
from .stateful_event_list_response import StatefulEventListResponse
from .stateful_event_metadata import StatefulEventMetadata
from .stateful_event_severity import StatefulEventSeverity
from .stateful_event_stream_type import StatefulEventStreamType
from .stateful_event_tags import StatefulEventTags
from .stateful_event_type import StatefulEventType
from .stateful_trigger_configuration import StatefulTriggerConfiguration
from .stream import Stream
from .stream_list_response import StreamListResponse
from .stream_stream_type import StreamStreamType
from .string_list_response import StringListResponse
from .stripe_card import StripeCard
from .stripe_info import StripeInfo
from .suggestion_request import SuggestionRequest
from .suggestion_structure_object_schema import SuggestionStructureObjectSchema
from .suggestion_structure_object_schema_properties import SuggestionStructureObjectSchemaProperties
from .suggestion_structure_schema import SuggestionStructureSchema
from .system_event import SystemEvent
from .system_event_metadata import SystemEventMetadata
from .system_event_stream_type import SystemEventStreamType
from .system_event_tags import SystemEventTags
from .system_event_type import SystemEventType
from .tag_parameters import TagParameters
from .tag_template import TagTemplate
from .tags_response import TagsResponse
from .task_summary import TaskSummary
from .task_summary_batch_request import TaskSummaryBatchRequest
from .task_summary_format import TaskSummaryFormat
from .task_summary_format_format import TaskSummaryFormatFormat
from .task_summary_format_list_response import TaskSummaryFormatListResponse
from .task_summary_metadata import TaskSummaryMetadata
from .task_summary_report import TaskSummaryReport
from .task_summary_stream_type import TaskSummaryStreamType
from .task_summary_tags import TaskSummaryTags
from .task_summary_type import TaskSummaryType
from .team import Team
from .team_list_response import TeamListResponse
from .team_tags import TeamTags
from .teleop_high_ping_reconnect_behaviors import TeleopHighPingReconnectBehaviors
from .teleop_joystick_axis_configuration import TeleopJoystickAxisConfiguration
from .teleop_joystick_axis_configuration_dimension import TeleopJoystickAxisConfigurationDimension
from .teleop_joystick_configuration import TeleopJoystickConfiguration
from .teleop_joystick_configuration_position import TeleopJoystickConfigurationPosition
from .teleop_request_data import TeleopRequestData
from .teleop_session_record import TeleopSessionRecord
from .teleop_session_record_metadata import TeleopSessionRecordMetadata
from .teleop_session_record_stream_type import TeleopSessionRecordStreamType
from .teleop_session_record_tags import TeleopSessionRecordTags
from .teleop_session_record_type import TeleopSessionRecordType
from .teleop_view_configuration import TeleopViewConfiguration
from .thinking_request import ThinkingRequest
from .threshold_event_trigger_condition import ThresholdEventTriggerCondition
from .threshold_event_trigger_condition_operator import ThresholdEventTriggerConditionOperator
from .threshold_event_trigger_condition_type import ThresholdEventTriggerConditionType
from .token_result import TokenResult
from .transform import Transform
from .transform_node import TransformNode
from .transform_tree_view_configuration import TransformTreeViewConfiguration
from .triggered_configuration import TriggeredConfiguration
from .triggered_event import TriggeredEvent
from .triggered_event_metadata import TriggeredEventMetadata
from .triggered_event_severity import TriggeredEventSeverity
from .triggered_event_stream_type import TriggeredEventStreamType
from .triggered_event_tags import TriggeredEventTags
from .triggered_event_type import TriggeredEventType
from .twist import Twist
from .updated_agent_version_response import UpdatedAgentVersionResponse
from .updated_configuration_response import UpdatedConfigurationResponse
from .updated_event_trigger_request import UpdatedEventTriggerRequest
from .updated_event_trigger_response import UpdatedEventTriggerResponse
from .usage_prices import UsagePrices
from .usage_record import UsageRecord
from .usage_record_query import UsageRecordQuery
from .usage_record_query_response import UsageRecordQueryResponse
from .usage_record_type import UsageRecordType
from .user import User
from .user_counts_by_account import UserCountsByAccount
from .user_counts_by_account_counts import UserCountsByAccountCounts
from .user_language import UserLanguage
from .user_list_response import UserListResponse
from .user_parameters import UserParameters
from .user_parameters_roles_item import UserParametersRolesItem
from .user_region import UserRegion
from .user_scope import UserScope
from .user_scope_types_item import UserScopeTypesItem
from .user_sms_opt_in_status import UserSmsOptInStatus
from .user_tags import UserTags
from .user_teleop_configuration import UserTeleopConfiguration
from .user_teleop_ros_stream_configuration import UserTeleopRosStreamConfiguration
from .user_teleop_twist_ros_topic_configuration import UserTeleopTwistRosTopicConfiguration
from .user_teleop_twist_ros_topic_configuration_type import UserTeleopTwistRosTopicConfigurationType
from .user_units import UserUnits
from .uuid_list_response import UuidListResponse
from .validation_configuration import ValidationConfiguration
from .vector_3 import Vector3
from .video import Video
from .video_device import VideoDevice
from .video_mime_type import VideoMimeType
from .view import View
from .view_configuration import ViewConfiguration
from .view_configuration_type import ViewConfigurationType
from .view_layout_type import ViewLayoutType
from .view_list_response import ViewListResponse
from .view_tags import ViewTags
from .webhook import Webhook
from .webhook_headers import WebhookHeaders
from .webhooks_info import WebhooksInfo

__all__ = (
    "Account",
    "AccountListResponse",
    "Adapter",
    "AdapterCascadingConfiguration",
    "AdapterCascadingConfigurationSpecificity",
    "AdapterCascadingConfigurationType",
    "AdapterConfiguration",
    "AdapterListResponse",
    "AnalyticsModule",
    "AnalyticsModuleLayout",
    "Annotation",
    "AnnotationField",
    "AnnotationFieldType",
    "AnnotationFieldValue",
    "AnnotationFieldValuesRequest",
    "AnnotationFieldValuesRequestTags",
    "AnnotationFieldValuesResponse",
    "AnnotationFieldValueTags",
    "AnnotationMetadata",
    "AnnotationStreamType",
    "AnnotationTags",
    "AnnotationTemplate",
    "AnnotationTemplateListResponse",
    "AnnotationTemplateTags",
    "AnnotationType",
    "ApplicationContext",
    "AudioDevice",
    "Authentication",
    "AutoResolveEventTriggerCondition",
    "AutoResolveEventTriggerConditionType",
    "AwsInfo",
    "AwsInfoOutputFormat",
    "BaseEvent",
    "BaseEventMetadata",
    "BaseEventStreamType",
    "BaseEventTags",
    "BaseEventTriggerPredicate",
    "BaseEventType",
    "Battery",
    "BatteryEventTriggerCondition",
    "BatteryEventTriggerConditionConditions",
    "BatteryEventTriggerConditionOperator",
    "BatteryEventTriggerConditionType",
    "BeginUploadRequest",
    "BeginUploadResponse",
    "BillingInfo",
    "BitCondition",
    "Bitset",
    "BitsetEventTriggerCondition",
    "BitsetEventTriggerConditionOperator",
    "BitsetEventTriggerConditionType",
    "BitsetViewConfiguration",
    "Board",
    "BoundingBox",
    "Camera",
    "CaptureSession",
    "CaptureSessionTags",
    "Challenge",
    "ChallengeType",
    "ChangePasswordRequest",
    "Channel",
    "ChannelListResponse",
    "ChargebeeCustomer",
    "ChatMessage",
    "ChatMessageListResponse",
    "ChatMessageRequest",
    "CheckSsoRequest",
    "CheckSsoResult",
    "CloudFile",
    "CloudFileListResponse",
    "CloudFileTags",
    "Command",
    "CommandDeliveryEvent",
    "CommandDeliveryEventMetadata",
    "CommandDeliveryEventStreamType",
    "CommandDeliveryEventTags",
    "CommandDeliveryEventType",
    "CommandListResponse",
    "CommandParameter",
    "CommandParameterMeta",
    "CommandProgress",
    "CommandQuery",
    "CommandRequest",
    "CommandRequestListResponse",
    "CommandResponse",
    "CommandResponseStreamType",
    "CommandResponseTags",
    "CommandStreamType",
    "CommandTags",
    "CommandTemplate",
    "CommandTemplateListResponse",
    "CommandTemplateParameterMeta",
    "CommandTemplateTags",
    "Comment",
    "CommentMetadata",
    "CommentStreamType",
    "CommentTags",
    "CommentType",
    "CompleteUploadRequest",
    "ConfirmForgotPasswordRequest",
    "CreateEventTriggerGroupRequest",
    "CreateEventTriggerGroupRequestTags",
    "CreateInterventionResponse",
    "CreateInterventionResponseInterventionType",
    "CreateInterventionResponseType",
    "CreateServiceAccountRequest",
    "CreateServiceAccountRequestTags",
    "CreateServiceAccountResponse",
    "CreateUserRequest",
    "CreateUserRequestLanguage",
    "CreateUserRequestRegion",
    "CreateUserRequestSmsOptInStatus",
    "CreateUserRequestTags",
    "CreateUserRequestUnits",
    "CustomEvent",
    "CustomEventBatchRequest",
    "CustomEventMetadata",
    "CustomEventSeverity",
    "CustomEventStreamType",
    "CustomEventTags",
    "CustomEventType",
    "DatapointEvent",
    "DatapointEventMetadata",
    "DatapointEventSeverity",
    "DatapointEventStreamType",
    "DatapointEventTags",
    "DatapointEventType",
    "Device",
    "DeviceApplicationConfiguration",
    "DeviceApplicationConfigurationConfigurationMap",
    "DeviceBlobData",
    "DeviceConfiguration",
    "DeviceConfigurationDocument",
    "DeviceConfigurationDocumentTags",
    "DeviceConfigurationTemplate",
    "DeviceConfigurationTemplateListResponse",
    "DeviceConfigurationTemplateTags",
    "DeviceCredentials",
    "DeviceDetails",
    "DeviceDetailsListResponse",
    "DeviceDetailsTags",
    "DeviceDetailsType",
    "DeviceDiagnosticsConfiguration",
    "DeviceDiskConfiguration",
    "DeviceFollower",
    "DeviceListResponse",
    "DeviceOfflineEvent",
    "DeviceOfflineEventMetadata",
    "DeviceOfflineEventSeverity",
    "DeviceOfflineEventStreamType",
    "DeviceOfflineEventTags",
    "DeviceOfflineEventType",
    "DeviceOnlineEvent",
    "DeviceOnlineEventMetadata",
    "DeviceOnlineEventSeverity",
    "DeviceOnlineEventStreamType",
    "DeviceOnlineEventTags",
    "DeviceOnlineEventType",
    "DevicePortForwardingConfiguration",
    "DeviceProvisioning",
    "DeviceProvisioningRequest",
    "DeviceQuery",
    "DeviceQueryType",
    "DeviceReportedConfigurationState",
    "DeviceResourcesConfiguration",
    "DeviceRosConfiguration",
    "DeviceRosState",
    "DeviceScope",
    "DeviceScopeTypesItem",
    "DeviceState",
    "DeviceStateEnv",
    "DeviceStreamConfiguration",
    "DeviceStreamConfigurationQuality",
    "DeviceStreamConfigurationTags",
    "DeviceStreamCustomConfiguration",
    "DeviceStreamCustomConfigurationType",
    "DeviceStreamDirectoryWatchConfiguration",
    "DeviceStreamDirectoryWatchConfigurationFileType",
    "DeviceStreamDirectoryWatchConfigurationType",
    "DeviceStreamFileTailConfiguration",
    "DeviceStreamFileTailConfigurationFileFormat",
    "DeviceStreamFileTailConfigurationType",
    "DeviceStreamHardwareConfiguration",
    "DeviceStreamHardwareConfigurationHardwareType",
    "DeviceStreamHardwareConfigurationQuality",
    "DeviceStreamHardwareConfigurationType",
    "DeviceStreamRosLocalizationConfiguration",
    "DeviceStreamRosLocalizationConfigurationType",
    "DeviceStreamRosTopicConfiguration",
    "DeviceStreamRosTopicConfigurationType",
    "DeviceStreamRosTransformTreeConfiguration",
    "DeviceStreamRosTransformTreeConfigurationType",
    "DeviceStreamTransformConfiguration",
    "DeviceTags",
    "DeviceTelemetryConfiguration",
    "DeviceTeleopConfiguration",
    "DeviceTeleopCustomStreamConfiguration",
    "DeviceTeleopCustomStreamConfigurationMode",
    "DeviceTeleopCustomStreamConfigurationNumericControlVisualization",
    "DeviceTeleopCustomStreamConfigurationQuality",
    "DeviceTeleopCustomStreamConfigurationRtcStreamType",
    "DeviceTeleopHardwareStreamConfiguration",
    "DeviceTeleopHardwareStreamConfigurationHardwareType",
    "DeviceTeleopHardwareStreamConfigurationMode",
    "DeviceTeleopHardwareStreamConfigurationQuality",
    "DeviceTeleopHardwareStreamConfigurationRtcStreamType",
    "DeviceTeleopRosStreamConfiguration",
    "DeviceTeleopRosStreamConfigurationAudioCodec",
    "DeviceTeleopRosStreamConfigurationMode",
    "DeviceTeleopRosStreamConfigurationNumericControlVisualization",
    "DeviceTeleopRosStreamConfigurationQuality",
    "DeviceTeleopRosStreamConfigurationTopicType",
    "DeviceType",
    "EmailConfiguration",
    "EmailConfigurationEmailType",
    "EmailConfigurationLanguage",
    "EmailConfigurationListResponse",
    "EventCounts",
    "EventCountsByDevice",
    "EventExportSheetRequest",
    "EventExportSheetResult",
    "EventFilter",
    "EventFilterEventTypesItem",
    "EventFilterSeveritiesItem",
    "EventFilterTypesItem",
    "EventHistogram",
    "EventHistogramEntry",
    "EventListResponse",
    "EventQuery",
    "EventQueryEventTypesItem",
    "EventQuerySeveritiesItem",
    "EventQueryTypesItem",
    "EventSeekQuery",
    "EventSeekQueryDirection",
    "EventSeekQueryEventTypesItem",
    "EventSeekQuerySeveritiesItem",
    "EventSeekQueryTypesItem",
    "EventSort",
    "EventSortColumn",
    "EventSortOrder",
    "EventTrigger",
    "EventTriggerCommand",
    "EventTriggerEventType",
    "EventTriggerGroup",
    "EventTriggerGroupListResponse",
    "EventTriggerGroupSmsTags",
    "EventTriggerGroupTags",
    "EventTriggerListResponse",
    "EventTriggerSeverity",
    "EventTriggerSmsTags",
    "EventTriggerTags",
    "Exploration",
    "ExplorationListResponse",
    "ExternalLoginRequest",
    "File",
    "FileInfo",
    "Filter",
    "FilterTypesItem",
    "Fleet",
    "FleetListResponse",
    "FleetTags",
    "FocusedDatapoint",
    "ForgotPasswordRequest",
    "ForwardingConfiguration",
    "GeoIp",
    "GeoJsonIcon",
    "GeoJsonLayer",
    "GetFeaturesResponse",
    "GetFeaturesResponseFeaturesItem",
    "Goal",
    "GoogleAuthRequest",
    "GoogleInfo",
    "GoogleLoginRequest",
    "GoogleSheetParseResult",
    "GoogleSpreadsheetInspection",
    "GoogleStorageExport",
    "GoogleStorageInfo",
    "GoogleStorageInfoOutputFormat",
    "Group",
    "GroupListResponse",
    "GroupTags",
    "Health",
    "HealthStatus",
    "HttpIntegration",
    "HttpIntegrationBasicAuth",
    "HttpIntegrationBasicAuthType",
    "HttpIntegrationMethod",
    "HttpIntegrationNoAuth",
    "HttpIntegrationNoAuthType",
    "HwInfo",
    "Image",
    "ImageAnnotation",
    "ImageViewConfiguration",
    "ImageViewConfigurationMode",
    "IngestStreamData",
    "IngestStreamDataTags",
    "IngestStreamDataType",
    "InspectSpreadsheetRequest",
    "InspectSpreadsheetResponse",
    "IntervalEventFilter",
    "IntervalEventFilterEventTypesItem",
    "IntervalEventFilterInterval",
    "IntervalEventFilterSeveritiesItem",
    "IntervalEventFilterTypesItem",
    "InterventionRequest",
    "InterventionRequestControllerListOrder",
    "InterventionRequestInterventionType",
    "InterventionRequestListResponse",
    "InterventionRequestMetadata",
    "InterventionRequestSeverity",
    "InterventionRequestStreamType",
    "InterventionRequestTags",
    "InterventionRequestType",
    "InterventionResponse",
    "InterventionResponseInterventionType",
    "InterventionResponseMetadata",
    "InterventionResponseStreamType",
    "InterventionResponseTags",
    "InterventionResponseType",
    "JoystickConfiguration",
    "JoystickConfigurationAngular",
    "JoystickConfigurationLinear",
    "JsonEventTriggerCondition",
    "JsonEventTriggerConditionType",
    "KernelInfo",
    "KeyValue",
    "KeyValueQuery",
    "KeyValueTags",
    "Label",
    "LabeledPolygon",
    "LabelingRequestData",
    "LayoutModuleConfiguration",
    "LayoutModuleConfigurationModuleType",
    "Localization",
    "LocalizationViewConfiguration",
    "Location",
    "LocationModuleParameters",
    "LocationViewConfiguration",
    "LocationViewConfigurationBasemap",
    "LocationViewport",
    "LoginRequest",
    "LoginResult",
    "LookerInfo",
    "LookerLook",
    "Map",
    "Module",
    "NamedJsonSchema",
    "NamedJsonSchemaSchemaType",
    "Network",
    "NetworkInfo",
    "NodeGraphIntegration",
    "NodeInfo",
    "NumericCondition",
    "NumericSetEntry",
    "NumericSetEventTriggerCondition",
    "NumericSetEventTriggerConditionOperator",
    "NumericSetEventTriggerConditionType",
    "NumericViewConfiguration",
    "Odometry",
    "OnDemandBuffer",
    "OnDemandBufferBufferType",
    "OnDemandPresenceStreamItemGroup",
    "OnDemandPresenceStreamItemGroupDatapointType",
    "OnDemandPresenceTimeRange",
    "OnDemandState",
    "OnDemandStreamPresence",
    "OnvifDevice",
    "Organization",
    "OrganizationAddonBillingPeriod",
    "OrganizationFlagsItem",
    "OrganizationInvoiceBillingPeriod",
    "OrganizationPlan",
    "OrganizationSupportedRegionsItem",
    "OrganizationSupportTier",
    "OsInfo",
    "OverviewSettings",
    "PagerdutyInfo",
    "PartialAccount",
    "PartialAdapter",
    "PartialAnnotation",
    "PartialAnnotationMetadata",
    "PartialAnnotationStreamType",
    "PartialAnnotationTags",
    "PartialAnnotationTemplate",
    "PartialAnnotationTemplateTags",
    "PartialAnnotationType",
    "PartialChannel",
    "PartialCloudFile",
    "PartialCloudFileTags",
    "PartialCommand",
    "PartialCommandStreamType",
    "PartialCommandTags",
    "PartialCommandTemplate",
    "PartialCommandTemplateParameterMeta",
    "PartialCommandTemplateTags",
    "PartialComment",
    "PartialCommentMetadata",
    "PartialCommentStreamType",
    "PartialCommentTags",
    "PartialCommentType",
    "PartialDevice",
    "PartialDeviceConfigurationTemplate",
    "PartialDeviceConfigurationTemplateTags",
    "PartialDeviceTags",
    "PartialDeviceType",
    "PartialEmailConfiguration",
    "PartialEmailConfigurationEmailType",
    "PartialEmailConfigurationLanguage",
    "PartialEventTrigger",
    "PartialEventTriggerEventType",
    "PartialEventTriggerGroup",
    "PartialEventTriggerGroupSmsTags",
    "PartialEventTriggerGroupTags",
    "PartialEventTriggerSeverity",
    "PartialEventTriggerSmsTags",
    "PartialEventTriggerTags",
    "PartialFleet",
    "PartialFleetTags",
    "PartialGroup",
    "PartialGroupTags",
    "PartialHttpIntegration",
    "PartialHttpIntegrationMethod",
    "PartialNodeGraphIntegration",
    "PartialRole",
    "PartialRoleTags",
    "PartialSchedule",
    "PartialScheduleType",
    "PartialSsoConfiguration",
    "PartialSsoConfigurationAuthenticationFlow",
    "PartialStream",
    "PartialStreamStreamType",
    "PartialTeam",
    "PartialTeamTags",
    "PartialUser",
    "PartialUserLanguage",
    "PartialUserRegion",
    "PartialUserSmsOptInStatus",
    "PartialUserTags",
    "PartialUserUnits",
    "PartialView",
    "PartialViewLayoutType",
    "PartialViewTags",
    "Path",
    "PhysicalRequestData",
    "PointCloud",
    "PointCloudViewConfiguration",
    "PollCommandRequest",
    "PortForwardingSessionRecord",
    "PortForwardingSessionRecordMetadata",
    "PortForwardingSessionRecordStreamType",
    "PortForwardingSessionRecordTags",
    "PortForwardingSessionRecordType",
    "PresenceEventTriggerCondition",
    "PresenceEventTriggerConditionType",
    "Quaternion",
    "QueryFilesRequest",
    "QueryFilesResponse",
    "RefreshRequest",
    "RegexEventTriggerCondition",
    "RegexEventTriggerConditionType",
    "ReorderRequest",
    "ReorderRequestItem",
    "ResendConfirmationCodeRequest",
    "ResendInvitationRequest",
    "RespondToNewPasswordRequiredChallengeRequest",
    "Role",
    "RoleListResponse",
    "RoleTags",
    "RosTopic",
    "RtcInfo",
    "RtcInfoRtcIceServerProtocol",
    "RtcInfoRtcIceTransportPoliciesItem",
    "S3Export",
    "Schedule",
    "ScheduleListResponse",
    "SchedulesQuery",
    "ScheduleType",
    "ScopeFilter",
    "ScopeFilterTypesItem",
    "SelectionRequestData",
    "Share",
    "ShareListResponse",
    "SheetParameters",
    "SlackAuthRequest",
    "SlackInfo",
    "SlackWebhook",
    "SsoConfiguration",
    "SsoConfigurationAuthenticationFlow",
    "SsoConfigurationListResponse",
    "SsoGroupNameToTeamMapping",
    "StatefulEvent",
    "StatefulEventListResponse",
    "StatefulEventMetadata",
    "StatefulEventSeverity",
    "StatefulEventStreamType",
    "StatefulEventTags",
    "StatefulEventType",
    "StatefulTriggerConfiguration",
    "Stream",
    "StreamListResponse",
    "StreamStreamType",
    "StringListResponse",
    "StripeCard",
    "StripeInfo",
    "SuggestionRequest",
    "SuggestionStructureObjectSchema",
    "SuggestionStructureObjectSchemaProperties",
    "SuggestionStructureSchema",
    "SystemEvent",
    "SystemEventMetadata",
    "SystemEventStreamType",
    "SystemEventTags",
    "SystemEventType",
    "TagParameters",
    "TagsResponse",
    "TagTemplate",
    "TaskSummary",
    "TaskSummaryBatchRequest",
    "TaskSummaryFormat",
    "TaskSummaryFormatFormat",
    "TaskSummaryFormatListResponse",
    "TaskSummaryMetadata",
    "TaskSummaryReport",
    "TaskSummaryStreamType",
    "TaskSummaryTags",
    "TaskSummaryType",
    "Team",
    "TeamListResponse",
    "TeamTags",
    "TeleopHighPingReconnectBehaviors",
    "TeleopJoystickAxisConfiguration",
    "TeleopJoystickAxisConfigurationDimension",
    "TeleopJoystickConfiguration",
    "TeleopJoystickConfigurationPosition",
    "TeleopRequestData",
    "TeleopSessionRecord",
    "TeleopSessionRecordMetadata",
    "TeleopSessionRecordStreamType",
    "TeleopSessionRecordTags",
    "TeleopSessionRecordType",
    "TeleopViewConfiguration",
    "ThinkingRequest",
    "ThresholdEventTriggerCondition",
    "ThresholdEventTriggerConditionOperator",
    "ThresholdEventTriggerConditionType",
    "TokenResult",
    "Transform",
    "TransformNode",
    "TransformTreeViewConfiguration",
    "TriggeredConfiguration",
    "TriggeredEvent",
    "TriggeredEventMetadata",
    "TriggeredEventSeverity",
    "TriggeredEventStreamType",
    "TriggeredEventTags",
    "TriggeredEventType",
    "Twist",
    "UpdatedAgentVersionResponse",
    "UpdatedConfigurationResponse",
    "UpdatedEventTriggerRequest",
    "UpdatedEventTriggerResponse",
    "UsagePrices",
    "UsageRecord",
    "UsageRecordQuery",
    "UsageRecordQueryResponse",
    "UsageRecordType",
    "User",
    "UserCountsByAccount",
    "UserCountsByAccountCounts",
    "UserLanguage",
    "UserListResponse",
    "UserParameters",
    "UserParametersRolesItem",
    "UserRegion",
    "UserScope",
    "UserScopeTypesItem",
    "UserSmsOptInStatus",
    "UserTags",
    "UserTeleopConfiguration",
    "UserTeleopRosStreamConfiguration",
    "UserTeleopTwistRosTopicConfiguration",
    "UserTeleopTwistRosTopicConfigurationType",
    "UserUnits",
    "UuidListResponse",
    "ValidationConfiguration",
    "Vector3",
    "Video",
    "VideoDevice",
    "VideoMimeType",
    "View",
    "ViewConfiguration",
    "ViewConfigurationType",
    "ViewLayoutType",
    "ViewListResponse",
    "ViewTags",
    "Webhook",
    "WebhookHeaders",
    "WebhooksInfo",
)



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="SqlColumn")


@attr.s(auto_attribs=True)
class SqlColumn:
    """
    Attributes:
        name (str):
        data_type (str):
        is_nullable (bool):
        table_name (str):
    """

    name: str
    data_type: str
    is_nullable: bool
    table_name: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        data_type = self.data_type
        is_nullable = self.is_nullable
        table_name = self.table_name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "dataType": data_type,
                "isNullable": is_nullable,
                "tableName": table_name,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        data_type = d.pop("dataType")

        is_nullable = d.pop("isNullable")

        table_name = d.pop("tableName")

        sql_column = cls(
            name=name,
            data_type=data_type,
            is_nullable=is_nullable,
            table_name=table_name,
        )

        sql_column.additional_properties = d
        return sql_column

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import List
from formant.protos.model.v1 import navigation_pb2
from formant.sdk.agent.v1.localization.utils import validate_type, get_ros_module
from .transform import Transform
from uuid import uuid4


class Map:
    @classmethod
    def from_ros(cls, map):
        nav_msgs = get_ros_module("nav_msgs.msg")
        validate_type(map, nav_msgs.OccupancyGrid)
        return cls(
            map.info.resolution,
            map.info.width,
            map.info.height,
            origin=Transform.from_ros_pose(map.info.origin),
            occupancy_grid_data=map.data,
        )

    @classmethod
    def from_costmap(cls, costmap):
        nav2_msgs = get_ros_module("nav2_msgs.msg")
        validate_type(costmap, nav2_msgs.Costmap)

        return cls(
            costmap.metadata.resolution,
            costmap.metadata.size_x,
            costmap.metadata.size_y,
            origin=Transform.from_ros_pose(costmap.metadata.origin),
            occupancy_grid_data=costmap.data
        )

    def __init__(
        self,
        resolution,  # type: float
        width,  # type: float
        height,  # type:  float
        origin=Transform(),  # type: Transform
        transform_to_world=Transform(),  # type: Transform
        url=None,  # type: str
        raw_data=None,  # type: bytes
        occupancy_grid_data=None,  # type:  List[int]
    ):
        self.resolution = resolution
        self.width = width
        self.height = height
        self.origin = origin
        self.transform_to_world = transform_to_world
        self.url = url
        self.raw_data = raw_data
        self.occupancy_grid_data = occupancy_grid_data
        self.uuid = uuid4()

    def to_proto(self):
        map = navigation_pb2.Map(
            resolution=self.resolution,
            width=self.width,
            height=self.height,
            origin=self.origin.to_proto(),
            world_to_local=self.transform_to_world.to_proto(),
            url=self.url,
            raw=self.raw_data,
            uuid=str(self.uuid),
        )
        if self.occupancy_grid_data is not None:
            map.occupancy_grid.data.extend(self.occupancy_grid_data)
        return map



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.device_teleop_custom_stream_configuration_mode import DeviceTeleopCustomStreamConfigurationMode
from ..models.device_teleop_custom_stream_configuration_numeric_control_visualization import (
    DeviceTeleopCustomStreamConfigurationNumericControlVisualization,
)
from ..models.device_teleop_custom_stream_configuration_quality import DeviceTeleopCustomStreamConfigurationQuality
from ..models.device_teleop_custom_stream_configuration_rtc_stream_type import (
    DeviceTeleopCustomStreamConfigurationRtcStreamType,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="DeviceTeleopCustomStreamConfiguration")


@attr.s(auto_attribs=True)
class DeviceTeleopCustomStreamConfiguration:
    """
    Attributes:
        name (str):
        rtc_stream_type (DeviceTeleopCustomStreamConfigurationRtcStreamType):
        mode (DeviceTeleopCustomStreamConfigurationMode):
        value_stream_name (Union[Unset, str]):
        labels (Union[Unset, List[str]]):
        encode_video (Union[Unset, bool]):
        overlay_clock (Union[Unset, bool]):
        min_ (Union[Unset, float]):
        max_ (Union[Unset, float]):
        default_value (Union[Unset, float]):
        step (Union[Unset, float]):
        numeric_control_visualization (Union[Unset, DeviceTeleopCustomStreamConfigurationNumericControlVisualization]):
        quality (Union[Unset, DeviceTeleopCustomStreamConfigurationQuality]):
        mouse_events_target_stream (Union[Unset, str]):
        button_color (Union[Unset, str]):
        button_label (Union[Unset, str]):
        bitrate (Union[Unset, int]):
        disable_adaptive_quality (Union[Unset, bool]):
        joy_frequency (Union[Unset, float]):
        joy_disable_button_mapping (Union[Unset, bool]):
    """

    name: str
    rtc_stream_type: DeviceTeleopCustomStreamConfigurationRtcStreamType
    mode: DeviceTeleopCustomStreamConfigurationMode
    value_stream_name: Union[Unset, str] = UNSET
    labels: Union[Unset, List[str]] = UNSET
    encode_video: Union[Unset, bool] = UNSET
    overlay_clock: Union[Unset, bool] = UNSET
    min_: Union[Unset, float] = UNSET
    max_: Union[Unset, float] = UNSET
    default_value: Union[Unset, float] = UNSET
    step: Union[Unset, float] = UNSET
    numeric_control_visualization: Union[Unset, DeviceTeleopCustomStreamConfigurationNumericControlVisualization] = (
        UNSET
    )
    quality: Union[Unset, DeviceTeleopCustomStreamConfigurationQuality] = UNSET
    mouse_events_target_stream: Union[Unset, str] = UNSET
    button_color: Union[Unset, str] = UNSET
    button_label: Union[Unset, str] = UNSET
    bitrate: Union[Unset, int] = UNSET
    disable_adaptive_quality: Union[Unset, bool] = UNSET
    joy_frequency: Union[Unset, float] = UNSET
    joy_disable_button_mapping: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        rtc_stream_type = self.rtc_stream_type.value

        mode = self.mode.value

        value_stream_name = self.value_stream_name
        labels: Union[Unset, List[str]] = UNSET
        if not isinstance(self.labels, Unset):
            labels = self.labels

        encode_video = self.encode_video
        overlay_clock = self.overlay_clock
        min_ = self.min_
        max_ = self.max_
        default_value = self.default_value
        step = self.step
        numeric_control_visualization: Union[Unset, str] = UNSET
        if not isinstance(self.numeric_control_visualization, Unset):
            numeric_control_visualization = self.numeric_control_visualization.value

        quality: Union[Unset, str] = UNSET
        if not isinstance(self.quality, Unset):
            quality = self.quality.value

        mouse_events_target_stream = self.mouse_events_target_stream
        button_color = self.button_color
        button_label = self.button_label
        bitrate = self.bitrate
        disable_adaptive_quality = self.disable_adaptive_quality
        joy_frequency = self.joy_frequency
        joy_disable_button_mapping = self.joy_disable_button_mapping

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "rtcStreamType": rtc_stream_type,
                "mode": mode,
            }
        )
        if value_stream_name is not UNSET:
            field_dict["valueStreamName"] = value_stream_name
        if labels is not UNSET:
            field_dict["labels"] = labels
        if encode_video is not UNSET:
            field_dict["encodeVideo"] = encode_video
        if overlay_clock is not UNSET:
            field_dict["overlayClock"] = overlay_clock
        if min_ is not UNSET:
            field_dict["min"] = min_
        if max_ is not UNSET:
            field_dict["max"] = max_
        if default_value is not UNSET:
            field_dict["defaultValue"] = default_value
        if step is not UNSET:
            field_dict["step"] = step
        if numeric_control_visualization is not UNSET:
            field_dict["numericControlVisualization"] = numeric_control_visualization
        if quality is not UNSET:
            field_dict["quality"] = quality
        if mouse_events_target_stream is not UNSET:
            field_dict["mouseEventsTargetStream"] = mouse_events_target_stream
        if button_color is not UNSET:
            field_dict["buttonColor"] = button_color
        if button_label is not UNSET:
            field_dict["buttonLabel"] = button_label
        if bitrate is not UNSET:
            field_dict["bitrate"] = bitrate
        if disable_adaptive_quality is not UNSET:
            field_dict["disableAdaptiveQuality"] = disable_adaptive_quality
        if joy_frequency is not UNSET:
            field_dict["joyFrequency"] = joy_frequency
        if joy_disable_button_mapping is not UNSET:
            field_dict["joyDisableButtonMapping"] = joy_disable_button_mapping

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        rtc_stream_type = DeviceTeleopCustomStreamConfigurationRtcStreamType(d.pop("rtcStreamType"))

        mode = DeviceTeleopCustomStreamConfigurationMode(d.pop("mode"))

        value_stream_name = d.pop("valueStreamName", UNSET)

        labels = cast(List[str], d.pop("labels", UNSET))

        encode_video = d.pop("encodeVideo", UNSET)

        overlay_clock = d.pop("overlayClock", UNSET)

        min_ = d.pop("min", UNSET)

        max_ = d.pop("max", UNSET)

        default_value = d.pop("defaultValue", UNSET)

        step = d.pop("step", UNSET)

        _numeric_control_visualization = d.pop("numericControlVisualization", UNSET)
        numeric_control_visualization: Union[Unset, DeviceTeleopCustomStreamConfigurationNumericControlVisualization]
        if isinstance(_numeric_control_visualization, Unset):
            numeric_control_visualization = UNSET
        else:
            numeric_control_visualization = DeviceTeleopCustomStreamConfigurationNumericControlVisualization(
                _numeric_control_visualization
            )

        _quality = d.pop("quality", UNSET)
        quality: Union[Unset, DeviceTeleopCustomStreamConfigurationQuality]
        if isinstance(_quality, Unset):
            quality = UNSET
        else:
            quality = DeviceTeleopCustomStreamConfigurationQuality(_quality)

        mouse_events_target_stream = d.pop("mouseEventsTargetStream", UNSET)

        button_color = d.pop("buttonColor", UNSET)

        button_label = d.pop("buttonLabel", UNSET)

        bitrate = d.pop("bitrate", UNSET)

        disable_adaptive_quality = d.pop("disableAdaptiveQuality", UNSET)

        joy_frequency = d.pop("joyFrequency", UNSET)

        joy_disable_button_mapping = d.pop("joyDisableButtonMapping", UNSET)

        device_teleop_custom_stream_configuration = cls(
            name=name,
            rtc_stream_type=rtc_stream_type,
            mode=mode,
            value_stream_name=value_stream_name,
            labels=labels,
            encode_video=encode_video,
            overlay_clock=overlay_clock,
            min_=min_,
            max_=max_,
            default_value=default_value,
            step=step,
            numeric_control_visualization=numeric_control_visualization,
            quality=quality,
            mouse_events_target_stream=mouse_events_target_stream,
            button_color=button_color,
            button_label=button_label,
            bitrate=bitrate,
            disable_adaptive_quality=disable_adaptive_quality,
            joy_frequency=joy_frequency,
            joy_disable_button_mapping=joy_disable_button_mapping,
        )

        device_teleop_custom_stream_configuration.additional_properties = d
        return device_teleop_custom_stream_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_admin_api_client.models import AdapterCascadingConfigurationType, Adapter, AdapterConfiguration, AdapterCascadingConfigurationSpecificity, AdapterListResponse, AdapterCascadingConfiguration
from formant.sdk.cloud.v2.formant_admin_api_client.api.adapter import adapter_controller_post, adapter_controller_delete
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
from typing import Any



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.teleop_joystick_configuration_position import TeleopJoystickConfigurationPosition
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.teleop_joystick_axis_configuration import TeleopJoystickAxisConfiguration


T = TypeVar("T", bound="TeleopJoystickConfiguration")


@attr.s(auto_attribs=True)
class TeleopJoystickConfiguration:
    """
    Attributes:
        position (Union[Unset, TeleopJoystickConfigurationPosition]):
        disable_trigger_joystick_mapping (Union[Unset, bool]):
        disable_gamepad_and_keyboard (Union[Unset, bool]):
        same_value_debounce (Union[Unset, float]):
        new_value_debounce (Union[Unset, float]):
        x (Union[Unset, TeleopJoystickAxisConfiguration]):
        y (Union[Unset, TeleopJoystickAxisConfiguration]):
        velocity_stream_name (Union[Unset, str]):
    """

    position: Union[Unset, TeleopJoystickConfigurationPosition] = UNSET
    disable_trigger_joystick_mapping: Union[Unset, bool] = UNSET
    disable_gamepad_and_keyboard: Union[Unset, bool] = UNSET
    same_value_debounce: Union[Unset, float] = UNSET
    new_value_debounce: Union[Unset, float] = UNSET
    x: Union[Unset, "TeleopJoystickAxisConfiguration"] = UNSET
    y: Union[Unset, "TeleopJoystickAxisConfiguration"] = UNSET
    velocity_stream_name: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        position: Union[Unset, str] = UNSET
        if not isinstance(self.position, Unset):
            position = self.position.value

        disable_trigger_joystick_mapping = self.disable_trigger_joystick_mapping
        disable_gamepad_and_keyboard = self.disable_gamepad_and_keyboard
        same_value_debounce = self.same_value_debounce
        new_value_debounce = self.new_value_debounce
        x: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.x, Unset):
            x = self.x.to_dict()

        y: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.y, Unset):
            y = self.y.to_dict()

        velocity_stream_name = self.velocity_stream_name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if position is not UNSET:
            field_dict["position"] = position
        if disable_trigger_joystick_mapping is not UNSET:
            field_dict["disableTriggerJoystickMapping"] = disable_trigger_joystick_mapping
        if disable_gamepad_and_keyboard is not UNSET:
            field_dict["disableGamepadAndKeyboard"] = disable_gamepad_and_keyboard
        if same_value_debounce is not UNSET:
            field_dict["sameValueDebounce"] = same_value_debounce
        if new_value_debounce is not UNSET:
            field_dict["newValueDebounce"] = new_value_debounce
        if x is not UNSET:
            field_dict["x"] = x
        if y is not UNSET:
            field_dict["y"] = y
        if velocity_stream_name is not UNSET:
            field_dict["velocityStreamName"] = velocity_stream_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.teleop_joystick_axis_configuration import TeleopJoystickAxisConfiguration

        d = src_dict.copy()
        _position = d.pop("position", UNSET)
        position: Union[Unset, TeleopJoystickConfigurationPosition]
        if isinstance(_position, Unset):
            position = UNSET
        else:
            position = TeleopJoystickConfigurationPosition(_position)

        disable_trigger_joystick_mapping = d.pop("disableTriggerJoystickMapping", UNSET)

        disable_gamepad_and_keyboard = d.pop("disableGamepadAndKeyboard", UNSET)

        same_value_debounce = d.pop("sameValueDebounce", UNSET)

        new_value_debounce = d.pop("newValueDebounce", UNSET)

        _x = d.pop("x", UNSET)
        x: Union[Unset, TeleopJoystickAxisConfiguration]
        if isinstance(_x, Unset):
            x = UNSET
        else:
            x = TeleopJoystickAxisConfiguration.from_dict(_x)

        _y = d.pop("y", UNSET)
        y: Union[Unset, TeleopJoystickAxisConfiguration]
        if isinstance(_y, Unset):
            y = UNSET
        else:
            y = TeleopJoystickAxisConfiguration.from_dict(_y)

        velocity_stream_name = d.pop("velocityStreamName", UNSET)

        teleop_joystick_configuration = cls(
            position=position,
            disable_trigger_joystick_mapping=disable_trigger_joystick_mapping,
            disable_gamepad_and_keyboard=disable_gamepad_and_keyboard,
            same_value_debounce=same_value_debounce,
            new_value_debounce=new_value_debounce,
            x=x,
            y=y,
            velocity_stream_name=velocity_stream_name,
        )

        teleop_joystick_configuration.additional_properties = d
        return teleop_joystick_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/model/v1/ros.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from formant.protos.model.v1 import math_pb2 as protos_dot_model_dot_v1_dot_math__pb2
from formant.protos.model.v1 import navigation_pb2 as protos_dot_model_dot_v1_dot_navigation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/model/v1/ros.proto',
  package='v1.model',
  syntax='proto3',
  serialized_options=b'Z)github.com/FormantIO/genproto/go/v1/model',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19protos/model/v1/ros.proto\x12\x08v1.model\x1a\x1aprotos/model/v1/math.proto\x1a protos/model/v1/navigation.proto\"<\n\x08ROSTopic\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0c\x65ncode_video\x18\x03 \x01(\x08\"\x9a\x01\n\x0fROSLocalization\x12\x11\n\tmap_topic\x18\x01 \x01(\t\x12\x12\n\nodom_topic\x18\x02 \x01(\t\x12\x1a\n\x12point_cloud_topics\x18\x03 \x03(\t\x12\x12\n\npath_topic\x18\x04 \x01(\t\x12\x12\n\ngoal_topic\x18\x05 \x01(\t\x12\x1c\n\x14\x62\x61se_reference_frame\x18\x06 \x01(\t\"0\n\x10ROSTransformTree\x12\x1c\n\x14\x62\x61se_reference_frame\x18\x01 \x01(\t\"\x9d\x03\n\x13ROSMessageToPublish\x12\x0e\n\x06stream\x18\x01 \x01(\t\x12\x10\n\x08\x66rame_id\x18\x07 \x01(\t\x12\x11\n\ttimestamp\x18\x08 \x01(\x04\x12 \n\x05twist\x18\x02 \x01(\x0b\x32\x0f.v1.model.TwistH\x00\x12\x0e\n\x04\x62ool\x18\x03 \x01(\x08H\x00\x12\x1a\n\x10\x63ompressed_image\x18\x04 \x01(\x0cH\x00\x12\x0e\n\x04text\x18\x05 \x01(\tH\x00\x12#\n\x04pose\x18\x06 \x01(\x0b\x32\x13.v1.model.TransformH\x00\x12\"\n\x06goalID\x18\t \x01(\x0b\x32\x10.v1.model.GoalIDH\x00\x12$\n\x07numeric\x18\n \x01(\x0b\x32\x11.v1.model.NumericH\x00\x12<\n\x14pose_with_covariance\x18\x0b \x01(\x0b\x32\x1c.v1.model.PoseWithCovarianceH\x00\x12 \n\x05point\x18\x0c \x01(\x0b\x32\x0f.v1.model.PointH\x00\x12\x1c\n\x03joy\x18\r \x01(\x0b\x32\r.v1.model.JoyH\x00\x42\x06\n\x04\x64\x61ta*\xd7\x03\n\x0cROSTopicType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x11\n\rSTD_MSGS_BOOL\x10\x01\x12 \n\x1cSENSOR_MSGS_COMPRESSED_IMAGE\x10\x02\x12\x13\n\x0fSTD_MSGS_STRING\x10\x03\x12\x16\n\x12GEOMETRY_MSGS_POSE\x10\x04\x12\x19\n\x15\x41\x43TIONLIB_MSGS_GOALID\x10\x05\x12\x17\n\x13GEOMETRY_MSGS_TWIST\x10\x06\x12\x14\n\x10H264_VIDEO_FRAME\x10\x07\x12\x0f\n\x0b\x41UDIO_CHUNK\x10\x08\x12\x14\n\x10STD_MSGS_FLOAT64\x10\t\x12\x1b\n\x17SENSOR_MSGS_JOINT_STATE\x10\n\x12&\n\"GEOMETRY_MSGS_POSE_WITH_COVARIANCE\x10\x0b\x12\x1c\n\x18SENSOR_MSGS_POINT_CLOUD2\x10\x0c\x12\x1a\n\x16SENSOR_MSGS_LASER_SCAN\x10\r\x12\x17\n\x13GEOMETRY_MSGS_POINT\x10\x0e\x12#\n\x1fVISUALIZATION_MSGS_MARKER_ARRAY\x10\x0f\x12\x15\n\x11NAV_MSGS_ODOMETRY\x10\x10\x12\x13\n\x0fSENSOR_MSGS_JOY\x10\x11\x42+Z)github.com/FormantIO/genproto/go/v1/modelb\x06proto3'
  ,
  dependencies=[protos_dot_model_dot_v1_dot_math__pb2.DESCRIPTOR,protos_dot_model_dot_v1_dot_navigation__pb2.DESCRIPTOR,])

_ROSTOPICTYPE = _descriptor.EnumDescriptor(
  name='ROSTopicType',
  full_name='v1.model.ROSTopicType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STD_MSGS_BOOL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SENSOR_MSGS_COMPRESSED_IMAGE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STD_MSGS_STRING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEOMETRY_MSGS_POSE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIONLIB_MSGS_GOALID', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEOMETRY_MSGS_TWIST', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='H264_VIDEO_FRAME', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUDIO_CHUNK', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STD_MSGS_FLOAT64', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SENSOR_MSGS_JOINT_STATE', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEOMETRY_MSGS_POSE_WITH_COVARIANCE', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SENSOR_MSGS_POINT_CLOUD2', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SENSOR_MSGS_LASER_SCAN', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GEOMETRY_MSGS_POINT', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VISUALIZATION_MSGS_MARKER_ARRAY', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NAV_MSGS_ODOMETRY', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SENSOR_MSGS_JOY', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=787,
  serialized_end=1258,
)
_sym_db.RegisterEnumDescriptor(_ROSTOPICTYPE)

ROSTopicType = enum_type_wrapper.EnumTypeWrapper(_ROSTOPICTYPE)
UNKNOWN = 0
STD_MSGS_BOOL = 1
SENSOR_MSGS_COMPRESSED_IMAGE = 2
STD_MSGS_STRING = 3
GEOMETRY_MSGS_POSE = 4
ACTIONLIB_MSGS_GOALID = 5
GEOMETRY_MSGS_TWIST = 6
H264_VIDEO_FRAME = 7
AUDIO_CHUNK = 8
STD_MSGS_FLOAT64 = 9
SENSOR_MSGS_JOINT_STATE = 10
GEOMETRY_MSGS_POSE_WITH_COVARIANCE = 11
SENSOR_MSGS_POINT_CLOUD2 = 12
SENSOR_MSGS_LASER_SCAN = 13
GEOMETRY_MSGS_POINT = 14
VISUALIZATION_MSGS_MARKER_ARRAY = 15
NAV_MSGS_ODOMETRY = 16
SENSOR_MSGS_JOY = 17



_ROSTOPIC = _descriptor.Descriptor(
  name='ROSTopic',
  full_name='v1.model.ROSTopic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='v1.model.ROSTopic.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='v1.model.ROSTopic.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encode_video', full_name='v1.model.ROSTopic.encode_video', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=161,
)


_ROSLOCALIZATION = _descriptor.Descriptor(
  name='ROSLocalization',
  full_name='v1.model.ROSLocalization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_topic', full_name='v1.model.ROSLocalization.map_topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='odom_topic', full_name='v1.model.ROSLocalization.odom_topic', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point_cloud_topics', full_name='v1.model.ROSLocalization.point_cloud_topics', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_topic', full_name='v1.model.ROSLocalization.path_topic', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='goal_topic', full_name='v1.model.ROSLocalization.goal_topic', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_reference_frame', full_name='v1.model.ROSLocalization.base_reference_frame', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=318,
)


_ROSTRANSFORMTREE = _descriptor.Descriptor(
  name='ROSTransformTree',
  full_name='v1.model.ROSTransformTree',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_reference_frame', full_name='v1.model.ROSTransformTree.base_reference_frame', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=368,
)


_ROSMESSAGETOPUBLISH = _descriptor.Descriptor(
  name='ROSMessageToPublish',
  full_name='v1.model.ROSMessageToPublish',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream', full_name='v1.model.ROSMessageToPublish.stream', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_id', full_name='v1.model.ROSMessageToPublish.frame_id', index=1,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='v1.model.ROSMessageToPublish.timestamp', index=2,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='twist', full_name='v1.model.ROSMessageToPublish.twist', index=3,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bool', full_name='v1.model.ROSMessageToPublish.bool', index=4,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compressed_image', full_name='v1.model.ROSMessageToPublish.compressed_image', index=5,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='v1.model.ROSMessageToPublish.text', index=6,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose', full_name='v1.model.ROSMessageToPublish.pose', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='goalID', full_name='v1.model.ROSMessageToPublish.goalID', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numeric', full_name='v1.model.ROSMessageToPublish.numeric', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose_with_covariance', full_name='v1.model.ROSMessageToPublish.pose_with_covariance', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point', full_name='v1.model.ROSMessageToPublish.point', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='joy', full_name='v1.model.ROSMessageToPublish.joy', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='v1.model.ROSMessageToPublish.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=371,
  serialized_end=784,
)

_ROSMESSAGETOPUBLISH.fields_by_name['twist'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TWIST
_ROSMESSAGETOPUBLISH.fields_by_name['pose'].message_type = protos_dot_model_dot_v1_dot_math__pb2._TRANSFORM
_ROSMESSAGETOPUBLISH.fields_by_name['goalID'].message_type = protos_dot_model_dot_v1_dot_navigation__pb2._GOALID
_ROSMESSAGETOPUBLISH.fields_by_name['numeric'].message_type = protos_dot_model_dot_v1_dot_math__pb2._NUMERIC
_ROSMESSAGETOPUBLISH.fields_by_name['pose_with_covariance'].message_type = protos_dot_model_dot_v1_dot_navigation__pb2._POSEWITHCOVARIANCE
_ROSMESSAGETOPUBLISH.fields_by_name['point'].message_type = protos_dot_model_dot_v1_dot_math__pb2._POINT
_ROSMESSAGETOPUBLISH.fields_by_name['joy'].message_type = protos_dot_model_dot_v1_dot_navigation__pb2._JOY
_ROSMESSAGETOPUBLISH.oneofs_by_name['data'].fields.append(
  _ROSMESSAGETOPUBLISH.fields_by_name['twist'])
_ROSMESSAGETOPUBLISH.fields_by_name['twist'].containing_oneof = _ROSMESSAGETOPUBLISH.oneofs_by_name['data']
_ROSMESSAGETOPUBLISH.oneofs_by_name['data'].fields.append(
  _ROSMESSAGETOPUBLISH.fields_by_name['bool'])
_ROSMESSAGETOPUBLISH.fields_by_name['bool'].containing_oneof = _ROSMESSAGETOPUBLISH.oneofs_by_name['data']
_ROSMESSAGETOPUBLISH.oneofs_by_name['data'].fields.append(
  _ROSMESSAGETOPUBLISH.fields_by_name['compressed_image'])
_ROSMESSAGETOPUBLISH.fields_by_name['compressed_image'].containing_oneof = _ROSMESSAGETOPUBLISH.oneofs_by_name['data']
_ROSMESSAGETOPUBLISH.oneofs_by_name['data'].fields.append(
  _ROSMESSAGETOPUBLISH.fields_by_name['text'])
_ROSMESSAGETOPUBLISH.fields_by_name['text'].containing_oneof = _ROSMESSAGETOPUBLISH.oneofs_by_name['data']
_ROSMESSAGETOPUBLISH.oneofs_by_name['data'].fields.append(
  _ROSMESSAGETOPUBLISH.fields_by_name['pose'])
_ROSMESSAGETOPUBLISH.fields_by_name['pose'].containing_oneof = _ROSMESSAGETOPUBLISH.oneofs_by_name['data']
_ROSMESSAGETOPUBLISH.oneofs_by_name['data'].fields.append(
  _ROSMESSAGETOPUBLISH.fields_by_name['goalID'])
_ROSMESSAGETOPUBLISH.fields_by_name['goalID'].containing_oneof = _ROSMESSAGETOPUBLISH.oneofs_by_name['data']
_ROSMESSAGETOPUBLISH.oneofs_by_name['data'].fields.append(
  _ROSMESSAGETOPUBLISH.fields_by_name['numeric'])
_ROSMESSAGETOPUBLISH.fields_by_name['numeric'].containing_oneof = _ROSMESSAGETOPUBLISH.oneofs_by_name['data']
_ROSMESSAGETOPUBLISH.oneofs_by_name['data'].fields.append(
  _ROSMESSAGETOPUBLISH.fields_by_name['pose_with_covariance'])
_ROSMESSAGETOPUBLISH.fields_by_name['pose_with_covariance'].containing_oneof = _ROSMESSAGETOPUBLISH.oneofs_by_name['data']
_ROSMESSAGETOPUBLISH.oneofs_by_name['data'].fields.append(
  _ROSMESSAGETOPUBLISH.fields_by_name['point'])
_ROSMESSAGETOPUBLISH.fields_by_name['point'].containing_oneof = _ROSMESSAGETOPUBLISH.oneofs_by_name['data']
_ROSMESSAGETOPUBLISH.oneofs_by_name['data'].fields.append(
  _ROSMESSAGETOPUBLISH.fields_by_name['joy'])
_ROSMESSAGETOPUBLISH.fields_by_name['joy'].containing_oneof = _ROSMESSAGETOPUBLISH.oneofs_by_name['data']
DESCRIPTOR.message_types_by_name['ROSTopic'] = _ROSTOPIC
DESCRIPTOR.message_types_by_name['ROSLocalization'] = _ROSLOCALIZATION
DESCRIPTOR.message_types_by_name['ROSTransformTree'] = _ROSTRANSFORMTREE
DESCRIPTOR.message_types_by_name['ROSMessageToPublish'] = _ROSMESSAGETOPUBLISH
DESCRIPTOR.enum_types_by_name['ROSTopicType'] = _ROSTOPICTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ROSTopic = _reflection.GeneratedProtocolMessageType('ROSTopic', (_message.Message,), {
  'DESCRIPTOR' : _ROSTOPIC,
  '__module__' : 'protos.model.v1.ros_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.ROSTopic)
  })
_sym_db.RegisterMessage(ROSTopic)

ROSLocalization = _reflection.GeneratedProtocolMessageType('ROSLocalization', (_message.Message,), {
  'DESCRIPTOR' : _ROSLOCALIZATION,
  '__module__' : 'protos.model.v1.ros_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.ROSLocalization)
  })
_sym_db.RegisterMessage(ROSLocalization)

ROSTransformTree = _reflection.GeneratedProtocolMessageType('ROSTransformTree', (_message.Message,), {
  'DESCRIPTOR' : _ROSTRANSFORMTREE,
  '__module__' : 'protos.model.v1.ros_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.ROSTransformTree)
  })
_sym_db.RegisterMessage(ROSTransformTree)

ROSMessageToPublish = _reflection.GeneratedProtocolMessageType('ROSMessageToPublish', (_message.Message,), {
  'DESCRIPTOR' : _ROSMESSAGETOPUBLISH,
  '__module__' : 'protos.model.v1.ros_pb2'
  # @@protoc_insertion_point(class_scope:v1.model.ROSMessageToPublish)
  })
_sym_db.RegisterMessage(ROSMessageToPublish)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import functools
import grpc
import traceback
from grpc_status import rpc_status
from formant.protos.agent.v1 import agent_pb2


def get_message(error):
    return error.message if hasattr(error, "message") else str(error)


class AgentException(IOError):
    """An exception has occured while communicating with the Formant agent."""


class Unavailable(AgentException):
    """
    The Formant agent is unavailable.
    It may be updating, not running, or running with a different address.
    """


class Throttled(AgentException):
    """
    The Formant agent has throttled a datapoint, and did not ingest it.
    This happens when datapoints are posted to a unique stream + tags pair,
    with frequency greater than the stream's frequency configuration.
    Note that events can still be triggered by datapoints that are throttled.
    """


class InvalidArgument(AgentException):
    """One or more arguments were invalid."""


class Unknown(AgentException):
    """An unknown error occurred."""


RPC_ERROR_CODE_MAPPING = {
    grpc.StatusCode.UNAVAILABLE: Unavailable,
    grpc.StatusCode.RESOURCE_EXHAUSTED: Throttled,
    grpc.StatusCode.INVALID_ARGUMENT: InvalidArgument,
    grpc.StatusCode.UNKNOWN: Unknown,
}


def handle_agent_exceptions(func):
    @functools.wraps(func)
    def _handle_agent_exceptions_inner(*args, **kwargs):
        error = None
        try:
            return func(*args, **kwargs)
        except grpc.RpcError as e:
            error = e

        code = error.code() if hasattr(error, "code") else None
        if (
            (code is None)
            or (args[0].ignore_throttled and code == grpc.StatusCode.RESOURCE_EXHAUSTED)
            or (args[0].ignore_unavailable and code == grpc.StatusCode.UNAVAILABLE)
        ):
            return

        raise_exception(error, code)

    return _handle_agent_exceptions_inner


def handle_grpc_exceptions(f):
    def handle_grpc_exceptions_inner(*args, **kwargs):
        try:
            return f(*args, **kwargs)
        except grpc.RpcError as e:
            if e.code() is not grpc.StatusCode.RESOURCE_EXHAUSTED:
                args[0].logger.warning(
                    "Agent RPC error in %s: %s" % (f.__name__, get_message(e))
                )
        except Exception as e:
            message = "".join(traceback.format_exception(None, e, e.__traceback__))
            args[0].logger.error("Non-grpc error in %s: %s" % (f.__name__, message))

    return handle_grpc_exceptions_inner


def handle_post_data_exceptions(f):
    def handle_post_data_exceptions_inner(*args, **kwargs):
        try:
            return f(*args, **kwargs)
        except grpc.RpcError as e:
            status = rpc_status.from_call(e)
            if status is None or not hasattr(status, "details"):
                args[0].logger.warn(
                    "Agent RPC error in %s: %s" % (f.__name__, get_message(e))
                )
                return
            for post_data_multi_error in status.details:
                if not post_data_multi_error.Is(
                    agent_pb2.PostDataMultiError.DESCRIPTOR
                ):
                    continue
                post_data_multi_error_pb = agent_pb2.PostDataMultiError()
                post_data_multi_error.Unpack(post_data_multi_error_pb)
                for error in post_data_multi_error_pb.errors:
                    if error.code is grpc.StatusCode.RESOURCE_EXHAUSTED.value[0]:
                        continue
                    args[0].logger.warn(
                        "Agent RPC error in %s: %s" % (f.__name__, get_message(error))
                    )
        except Exception as e:
            message = "".join(traceback.format_exception(None, e, e.__traceback__))
            args[0].logger.error("Non-grpc error in %s: %s" % (f.__name__, message))

    return handle_post_data_exceptions_inner


def raise_exception(error, code):
    exception_cls = RPC_ERROR_CODE_MAPPING.get(code, AgentException)
    message = str(error.details()) + "\n" + exception_cls.__doc__
    raise exception_cls(message)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
    from ..models.bounding_box import BoundingBox


T = TypeVar("T", bound="ImageAnnotation")


@attr.s(auto_attribs=True)
class ImageAnnotation:
    """
    Attributes:
        label (str):
        color (str):
        type (str):
        area (BoundingBox):
    """

    label: str
    color: str
    type: str
    area: "BoundingBox"
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        label = self.label
        color = self.color
        type = self.type
        area = self.area.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "label": label,
                "color": color,
                "type": type,
                "area": area,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.bounding_box import BoundingBox

        d = src_dict.copy()
        label = d.pop("label")

        color = d.pop("color")

        type = d.pop("type")

        area = BoundingBox.from_dict(d.pop("area"))

        image_annotation = cls(
            label=label,
            color=color,
            type=type,
            area=area,
        )

        image_annotation.additional_properties = d
        return image_annotation

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.event_sort_column import EventSortColumn
from ..models.event_sort_order import EventSortOrder

T = TypeVar("T", bound="EventSort")


@attr.s(auto_attribs=True)
class EventSort:
    """
    Attributes:
        column (EventSortColumn):
        order (EventSortOrder):
    """

    column: EventSortColumn
    order: EventSortOrder
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        column = self.column.value

        order = self.order.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "column": column,
                "order": order,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        column = EventSortColumn(d.pop("column"))

        order = EventSortOrder(d.pop("order"))

        event_sort = cls(
            column=column,
            order=order,
        )

        event_sort.additional_properties = d
        return event_sort

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.src.resources.resources import Resources
from formant.sdk.cloud.v2.formant_query_api_client.api.count import count_controller_active_devices
from formant.sdk.cloud.v2.formant_query_api_client.models.active_devices_query import ActiveDevicesQuery

class Count(Resources):

    def active_devices(self, active_devices_query: ActiveDevicesQuery):
        'Gets all the active devices during the timestamp'
        client = self._get_client()
        response = count_controller_active_devices.sync_detailed(client=client, json_body=active_devices_query)
        return response

    async def active_devices_async(self, active_devices_query: ActiveDevicesQuery):
        'Gets all the active devices during the timestamp'
        client = self._get_client()
        response = (await count_controller_active_devices.asyncio_detailed(client=client, json_body=active_devices_query))
        return response



import datetime
from typing import Any, Dict, List, Type, TypeVar

import attr
from dateutil.parser import isoparse

T = TypeVar("T", bound="FocusedDatapoint")


@attr.s(auto_attribs=True)
class FocusedDatapoint:
    """
    Attributes:
        stream_name (str):
        time (datetime.datetime):
    """

    stream_name: str
    time: datetime.datetime
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        stream_name = self.stream_name
        time = self.time.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "streamName": stream_name,
                "time": time,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        stream_name = d.pop("streamName")

        time = isoparse(d.pop("time"))

        focused_datapoint = cls(
            stream_name=stream_name,
            time=time,
        )

        focused_datapoint.additional_properties = d
        return focused_datapoint

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="Battery")


@attr.s(auto_attribs=True)
class Battery:
    """
    Attributes:
        percentage (float):
        voltage (Union[Unset, float]):
        current (Union[Unset, float]):
        charge (Union[Unset, float]):
    """

    percentage: float
    voltage: Union[Unset, float] = UNSET
    current: Union[Unset, float] = UNSET
    charge: Union[Unset, float] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        percentage = self.percentage
        voltage = self.voltage
        current = self.current
        charge = self.charge

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "percentage": percentage,
            }
        )
        if voltage is not UNSET:
            field_dict["voltage"] = voltage
        if current is not UNSET:
            field_dict["current"] = current
        if charge is not UNSET:
            field_dict["charge"] = charge

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        percentage = d.pop("percentage")

        voltage = d.pop("voltage", UNSET)

        current = d.pop("current", UNSET)

        charge = d.pop("charge", UNSET)

        battery = cls(
            percentage=percentage,
            voltage=voltage,
            current=current,
            charge=charge,
        )

        battery.additional_properties = d
        return battery

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class EventSortColumn(str, Enum):
    TYPE = "type"
    MESSAGE = "message"
    DEVICE_NAME = "device.name"
    TIME = "time"
    EVENT_CREATEDAT = "event.createdAt"
    EVENT_UPDATEDAT = "event.updatedAt"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="AdapterConfiguration")


@attr.s(auto_attribs=True)
class AdapterConfiguration:
    """
    Attributes:
        id (str):
        name (str):
        file_id (str):
        exec_command (str):
        configuration (Union[Unset, str]):
    """

    id: str
    name: str
    file_id: str
    exec_command: str
    configuration: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        name = self.name
        file_id = self.file_id
        exec_command = self.exec_command
        configuration = self.configuration

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "name": name,
                "fileId": file_id,
                "execCommand": exec_command,
            }
        )
        if configuration is not UNSET:
            field_dict["configuration"] = configuration

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        name = d.pop("name")

        file_id = d.pop("fileId")

        exec_command = d.pop("execCommand")

        configuration = d.pop("configuration", UNSET)

        adapter_configuration = cls(
            id=id,
            name=name,
            file_id=file_id,
            exec_command=exec_command,
            configuration=configuration,
        )

        adapter_configuration.additional_properties = d
        return adapter_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.suggestion_structure_object_schema_properties import SuggestionStructureObjectSchemaProperties


T = TypeVar("T", bound="SuggestionStructureObjectSchema")


@attr.s(auto_attribs=True)
class SuggestionStructureObjectSchema:
    """
    Attributes:
        type (str):
        properties (SuggestionStructureObjectSchemaProperties):
        required (Union[Unset, List[str]]):
    """

    type: str
    properties: "SuggestionStructureObjectSchemaProperties"
    required: Union[Unset, List[str]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        type = self.type
        properties = self.properties.to_dict()

        required: Union[Unset, List[str]] = UNSET
        if not isinstance(self.required, Unset):
            required = self.required

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "type": type,
                "properties": properties,
            }
        )
        if required is not UNSET:
            field_dict["required"] = required

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.suggestion_structure_object_schema_properties import SuggestionStructureObjectSchemaProperties

        d = src_dict.copy()
        type = d.pop("type")

        properties = SuggestionStructureObjectSchemaProperties.from_dict(d.pop("properties"))

        required = cast(List[str], d.pop("required", UNSET))

        suggestion_structure_object_schema = cls(
            type=type,
            properties=properties,
            required=required,
        )

        suggestion_structure_object_schema.additional_properties = d
        return suggestion_structure_object_schema

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.health_status import HealthStatus
from ..types import UNSET, Unset

T = TypeVar("T", bound="Health")


@attr.s(auto_attribs=True)
class Health:
    """
    Attributes:
        status (HealthStatus):
        clock_skew_ms (Union[Unset, int]):
    """

    status: HealthStatus
    clock_skew_ms: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        status = self.status.value

        clock_skew_ms = self.clock_skew_ms

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "status": status,
            }
        )
        if clock_skew_ms is not UNSET:
            field_dict["clockSkewMs"] = clock_skew_ms

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        status = HealthStatus(d.pop("status"))

        clock_skew_ms = d.pop("clockSkewMs", UNSET)

        health = cls(
            status=status,
            clock_skew_ms=clock_skew_ms,
        )

        health.additional_properties = d
        return health

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
